@@ -46,7 +46,7 @@ public:
     };
 
     explicit SpectacleCore(QObject *parent = nullptr);
-    ~SpectacleCore() override;
+    ~SpectacleCore() noexcept override;
 
     static SpectacleCore *instance();
 
@@ -92,7 +92,6 @@ public Q_SLOTS:
                            bool includeShadow = Settings::includeShadow());
     void cancelScreenshot();
     void showErrorMessage(const QString &message);
-    void onScreenshotFailed();
 
 Q_SIGNALS:
     void screenCaptureUrlChanged();
@@ -100,8 +99,8 @@ Q_SIGNALS:
     void captureProgressChanged();
 
     void allDone();
-    void dbusScreenshotFailed();
-    void dbusRecordingFailed();
+    void dbusScreenshotFailed(const QString &message);
+    void dbusRecordingFailed(const QString &message);
     void videoModeChanged(bool videoMode);
     void currentVideoChanged(const QUrl &currentVideo);
     void recordedTimeChanged();
